=== modified file 'bzrlib/win32utils.py'
--- bzrlib/win32utils.py	2011-12-12 18:32:33 +0000
+++ bzrlib/win32utils.py	2011-12-12 18:48:51 +0000
@@ -24,7 +24,10 @@
 import struct
 import sys
 
-from bzrlib import cmdline
+from bzrlib import (
+    cmdline,
+    symbol_versioning,
+    )
 from bzrlib.i18n import gettext
 
 # Windows version
@@ -248,28 +251,12 @@
     one that moves with the user as they logon to different machines, and
     a 'local' one that stays local to the machine.  This returns the 'roaming'
     directory, and thus is suitable for storing user-preferences, etc.
-
-    Returned value can be unicode or plain string.
-    To convert plain string to unicode use
-    s.decode(osutils.get_user_encoding())
-    (XXX - but see bug 262874, which asserts the correct encoding is 'mbcs')
     """
     appdata = _get_sh_special_folder_path(CSIDL_APPDATA)
     if appdata:
         return appdata
-    # from env variable
-    appdata = os.environ.get('APPDATA')
-    if appdata:
-        return appdata
-    # if we fall to this point we on win98
-    # at least try C:/WINDOWS/Application Data
-    windir = os.environ.get('windir')
-    if windir:
-        appdata = os.path.join(windir, 'Application Data')
-        if os.path.isdir(appdata):
-            return appdata
-    # did not find anything
-    return None
+    # Use APPDATA if defined, will return None if not
+    return get_environ_unicode('APPDATA')
 
 
 def get_local_appdata_location():
@@ -281,17 +268,12 @@
     a 'local' one that stays local to the machine.  This returns the 'local'
     directory, and thus is suitable for caches, temp files and other things
     which don't need to move with the user.
-
-    Returned value can be unicode or plain string.
-    To convert plain string to unicode use
-    s.decode(osutils.get_user_encoding())
-    (XXX - but see bug 262874, which asserts the correct encoding is 'mbcs')
     """
     local = _get_sh_special_folder_path(CSIDL_LOCAL_APPDATA)
     if local:
         return local
     # Vista supplies LOCALAPPDATA, but XP and earlier do not.
-    local = os.environ.get('LOCALAPPDATA')
+    local = get_environ_unicode('LOCALAPPDATA')
     if local:
         return local
     return get_appdata_location()
@@ -302,24 +284,22 @@
     Assume on win32 it's the <My Documents> folder.
     If location cannot be obtained return system drive root,
     i.e. C:\
-
-    Returned value can be unicode or plain string.
-    To convert plain string to unicode use
-    s.decode(osutils.get_user_encoding())
     """
     home = _get_sh_special_folder_path(CSIDL_PERSONAL)
     if home:
         return home
-    # try for HOME env variable
-    home = os.path.expanduser('~')
-    if home != '~':
+    home = get_environ_unicode('HOME')
+    if home is not None:
         return home
+    homepath = get_environ_unicode('HOMEPATH')
+    if homepath is not None:
+        return os.path.join(get_environ_unicode('HOMEDIR', ''), home)
     # at least return windows root directory
-    windir = os.environ.get('windir')
+    windir = get_environ_unicode('WINDIR')
     if windir:
         return os.path.splitdrive(windir)[0] + '/'
     # otherwise C:\ is good enough for 98% users
-    return 'C:/'
+    return unicode('C:/')
 
 
 def get_user_name():
@@ -342,7 +322,7 @@
             if GetUserName(buf, ctypes.byref(n)):
                 return buf.value
     # otherwise try env variables
-    return os.environ.get('USERNAME', None)
+    return get_environ_unicode('USERNAME')
 
 
 # 1 == ComputerNameDnsHostname, which returns "The DNS host name of the local
@@ -388,15 +368,7 @@
             if (GetComputerName is not None
                 and GetComputerName(buf, ctypes.byref(n))):
                 return buf.value
-    # otherwise try env variables, which will be 'mbcs' encoded
-    # on Windows (Python doesn't expose the native win32 unicode environment)
-    # According to this:
-    # http://msdn.microsoft.com/en-us/library/aa246807.aspx
-    # environment variables should always be encoded in 'mbcs'.
-    try:
-        return os.environ['COMPUTERNAME'].decode("mbcs")
-    except KeyError:
-        return None
+    return get_environ_unicode('COMPUTERNAME')
 
 
 def _ensure_unicode(s):
@@ -406,11 +378,11 @@
     return s
 
 
-def get_appdata_location_unicode():
-    return _ensure_unicode(get_appdata_location())
+get_appdata_location_unicode = symbol_versioning.deprecated_method(
+    symbol_versioning.deprecated_in((2, 5, 0)))(get_appdata_location)
 
-def get_home_location_unicode():
-    return _ensure_unicode(get_home_location())
+get_home_location_unicode = symbol_versioning.deprecated_method(
+    symbol_versioning.deprecated_in((2, 5, 0)))(get_home_location)
 
 def get_user_name_unicode():
     return _ensure_unicode(get_user_name())
@@ -433,7 +405,6 @@
         return path
 
 
-
 def glob_one(possible_glob):
     """Same as glob.glob().
 

